Learn R Programming

PowerfulMaxEigenpair (version 0.1.1)

powerful.seceig.tri: Tridiagonal matrix next to the maximal eigenpair

Description

Calculate the next to maximal eigenpair for the tridiagonal matrix by Thomas algorithm.

Usage

powerful.seceig.tri(a, b, digit.thresh = 6)

Arguments

a

The lower diagonal vector.

b

The upper diagonal vector.

digit.thresh

The precise level of output results.

Value

A list of eigenpair object are returned, with components \(z\), \(v\) and \(iter\).

z

The approximating sequence of the maximal eigenvalue.

v

The approximating eigenfunction of the corresponding eigenvector.

iter

The number of iterations.

Examples

Run this code
# NOT RUN {
nn = 8
a = c(1:(nn - 1))^2
b = c(1:(nn - 1))^2
powerful.seceig.tri(a, b, digit.thresh = 6)
# }

Run the code above in your browser using DataLab