The PowerfulMaxEigenpair package provides some auxillary functions and
five categories of important functions:
tridiag, thomas.tri.sol,
powerful.maxeig.tri and powerful.seceig.tri.
tridiag: generate tridiagonal matrix Q based on three input vectors.
thomas.tri.sol: construct the solution of linear equation (-Q-zI)w=v.
powerful.maxeig.tri: calculate the maximal eigenpair for the tridiagonal matrix by
Thomas algorithm.
powerful.seceig.tri: calculate next to the maximal eigenpair for the tridiagonal matrix by
Thomas algorithm.