powered by
Calculate the maximal eigenpair for the tridiagonal matrix by Thomas algorithm.
powerful.maxeig.tri(a, b, C, digit.thresh = 6)
The lower diagonal vector.
The upper diagonal vector.
The main diagonal vector.
The precise level of output results.
A list of eigenpair object are returned, with components \(z\), \(v\) and \(iter\).
The approximating sequence of the maximal eigenvalue.
The approximating eigenfunction of the corresponding eigenvector.
The number of iterations.
# NOT RUN { nn = 8 a = c(1:(nn - 1))^2 b = c(1:(nn - 1))^2 C = c(b[1], a[1:(nn - 2)] + b[2:(nn - 1)], a[nn - 1] + nn^2) powerful.maxeig.tri(a, b, C, digit.thresh = 6) # }
Run the code above in your browser using DataLab