powered by
Calculate the next to maximal eigenpair for the tridiagonal matrix by Thomas algorithm.
powerful.seceig.tri(a, b, digit.thresh = 6)
The lower diagonal vector.
The upper diagonal vector.
The precise level of output results.
A list of eigenpair object are returned, with components \(z\), \(v\) and \(iter\).
The approximating sequence of the maximal eigenvalue.
The approximating eigenfunction of the corresponding eigenvector.
The number of iterations.
# NOT RUN { nn = 8 a = c(1:(nn - 1))^2 b = c(1:(nn - 1))^2 powerful.seceig.tri(a, b, digit.thresh = 6) # }
Run the code above in your browser using DataLab